@@ -4,6 +4,7 @@ from grpc import StatusCode
 from grpc.aio import ServicerContext
 from delphai_utils.logging import logging
 import asyncio
+from functools import wraps
 
 def get_roles(provided_roles: Union[List[str], ServicerContext]):
   """
@@ -68,6 +69,7 @@ def authorize(required_roles: List[str], decission_logic: str = 'all'):
 
   def wrap(func):
     if not asyncio.iscoroutinefunction(func):
+      @wraps(func)
       def wrapped_func(self, request, context, *args, **kwargs):
         if (is_authorized(context, required_roles, decission_logic)):
           return func(self, request, context, *args, **kwargs)
@@ -77,6 +79,7 @@ def authorize(required_roles: List[str], decission_logic: str = 'all'):
           context.abort(StatusCode.PERMISSION_DENIED, details)
       return wrapped_func
     else:
+      @wraps(func)
       async def wrapped_func(self, request, context, *args, **kwargs):
         if (is_authorized(context, required_roles, decission_logic)):
           return await func(self, request, context, *args, **kwargs)
