@@ -8,6 +8,7 @@ from grpc_health.v1.health_pb2 import _HEALTH, HealthCheckResponse
 from delphai_utils.logging import logging
 from google.protobuf.descriptor import FileDescriptor
 from delphai_utils.gateway import start_gateway
+from delphai_utils.keycloak import update_public_keys
 import signal
 
 shutdown_event = asyncio.Event()
@@ -42,6 +43,7 @@ def start_server(server: Server, gateway: bool = True):
       gateway = start_gateway(server.__dict__['descriptor'])
       loop.create_task(gateway)
     loop.create_task(server.wait_for_termination())
+    loop.create_task(update_public_keys())
     loop.run_forever()
   except KeyboardInterrupt:
-    logging.info('stopped server (keyboard interrupt)')
\ No newline at end of file
+    logging.info('stopped server (keyboard interrupt)')
